<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

if ( ! function_exists( 'chrisporate_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Chrisporate Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function chrisporate_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'chrisporate_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'chrisporate_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Chrisporate Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function chrisporate_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'chrisporate_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'chrisporate_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Chrisporate Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function chrisporate_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'chrisporate_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Check if side menu section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_side_menu_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[side_menu]' )->value();
}


/**
 * Front Page Active Callbacks
 */

/**
 * Check if about section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_about_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[about_section_enable]' )->value();
}

/**
 * Check if about section content type is page.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[about_content_type]' )->value();
	return chrisporate_pro_is_about_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if about section content type is post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[about_content_type]' )->value();
	return chrisporate_pro_is_about_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[about_content_type]' )->value();
	return chrisporate_pro_is_about_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if about section skills is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_about_section_skills_enable( $control ) {
	return chrisporate_pro_is_about_section_enable( $control ) && $control->manager->get_setting( 'chrisporate_pro_theme_options[about_skills_enable]' )->value();
}

/**
 * Check if service section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_service_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[service_section_enable]' )->value();
}

/**
 * Check if service section title type is page.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_service_section_title_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[service_title_type]' )->value();
	return chrisporate_pro_is_service_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if service section title type is post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_service_section_title_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[service_title_type]' )->value();
	return chrisporate_pro_is_service_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if service section title type is custom.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_service_section_title_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[service_title_type]' )->value();
	return chrisporate_pro_is_service_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if service section content type is not demo and post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_service_section_count_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[service_content_type]' )->value();
	return chrisporate_pro_is_service_section_enable( $control ) && ( ! in_array( $content_type, array( 'demo', 'post' ) ) );
}

/**
 * Check if service section content type is post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[service_content_type]' )->value();
	return chrisporate_pro_is_service_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[service_content_type]' )->value();
	return chrisporate_pro_is_service_section_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if service section content type is page.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[service_content_type]' )->value();
	return chrisporate_pro_is_service_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if counter section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_counter_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[counter_section_enable]' )->value();
}


/**
 * Check if counter section content type is custom.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_counter_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[counter_content_type]' )->value();
	return chrisporate_pro_is_counter_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if portfolio section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_portfolio_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[portfolio_section_enable]' )->value();
}

/**
 * Check if portfolio section title type is page.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_portfolio_section_title_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[portfolio_title_type]' )->value();
	return chrisporate_pro_is_portfolio_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if portfolio section title type is post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_portfolio_section_title_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[portfolio_title_type]' )->value();
	return chrisporate_pro_is_portfolio_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if portfolio section title type is custom.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_portfolio_section_title_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[portfolio_title_type]' )->value();
	return chrisporate_pro_is_portfolio_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if portfolio section count enable.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_portfolio_section_count_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[portfolio_content_type]' )->value();
	return chrisporate_pro_is_portfolio_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'category' ) ) );
}

/**
 * Check if portfolio section content type is page.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_portfolio_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[portfolio_content_type]' )->value();
	return chrisporate_pro_is_portfolio_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if portfolio section content type is post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_portfolio_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[portfolio_content_type]' )->value();
	return chrisporate_pro_is_portfolio_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if portfolio section content type is category.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_portfolio_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[portfolio_content_type]' )->value();
	return chrisporate_pro_is_portfolio_section_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if author section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_author_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[author_section_enable]' )->value();
}

/**
 * Check if author section count enabled
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_author_section_count_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[author_content_type]' )->value();
	return chrisporate_pro_is_author_section_enable( $control ) && ( ! in_array( $content_type, array( 'demo', 'post' ) ) );
}

/**
 * Check if author section content type is post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_author_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[author_content_type]' )->value();
	return chrisporate_pro_is_author_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if author section content type is custom.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_author_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[author_content_type]' )->value();
	return chrisporate_pro_is_author_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if author section content type is category.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_author_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[author_content_type]' )->value();
	return chrisporate_pro_is_author_section_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if author section content type is page.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_author_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[author_content_type]' )->value();
	return chrisporate_pro_is_author_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if latest blog section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_latest_blog_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[latest_blog_section_enable]' )->value();
}

/**
 * Check if latest blog section title type is post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_latest_blog_section_title_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[latest_blog_title_type]' )->value();
	return chrisporate_pro_is_latest_blog_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if latest blog section title type is page.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_latest_blog_section_title_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[latest_blog_title_type]' )->value();
	return chrisporate_pro_is_latest_blog_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if latest blog section title type is custom.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_latest_blog_section_title_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[latest_blog_title_type]' )->value();
	return chrisporate_pro_is_latest_blog_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if latest blog section content type is not demo.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_latest_blog_section_content_not_demo( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[latest_blog_content_type]' )->value();
	return chrisporate_pro_is_latest_blog_section_enable( $control ) && ( 'demo' !== $content_type );
}

/**
 * Check if latest blog section content type is category.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_latest_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[latest_blog_content_type]' )->value();
	return chrisporate_pro_is_latest_blog_section_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if latest blog section content type is all posts.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_latest_blog_section_content_all_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[latest_blog_content_type]' )->value();
	return chrisporate_pro_is_latest_blog_section_enable( $control ) && ( 'all' === $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_testimonial_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[testimonial_section_enable]' )->value();
}

/**
 * Check if testimonial section count enable.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_testimonial_section_count_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[testimonial_content_type]' )->value();
	return chrisporate_pro_is_testimonial_section_enable( $control ) && ( ! in_array( $content_type, array( 'post', 'demo' ) ) );
}

/**
 * Check if testimonial section content post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[testimonial_content_type]' )->value();
	return chrisporate_pro_is_testimonial_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if testimonial section content custom.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[testimonial_content_type]' )->value();
	return chrisporate_pro_is_testimonial_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if testimonial section content category.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[testimonial_content_type]' )->value();
	return chrisporate_pro_is_testimonial_section_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if testimonial section content page.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[testimonial_content_type]' )->value();
	return chrisporate_pro_is_testimonial_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_team_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[team_section_enable]' )->value();
}

/**
 * Check if team section title custom.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_team_section_title_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[team_title_type]' )->value();
	return chrisporate_pro_is_team_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if team section title post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_team_section_title_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[team_title_type]' )->value();
	return chrisporate_pro_is_team_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if team section title page.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_team_section_title_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[team_title_type]' )->value();
	return chrisporate_pro_is_team_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if team section content page.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[team_content_type]' )->value();
	return chrisporate_pro_is_team_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if team section content post.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[team_content_type]' )->value();
	return chrisporate_pro_is_team_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if team section content category.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[team_content_type]' )->value();
	return chrisporate_pro_is_team_section_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if team section content custom.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[team_content_type]' )->value();
	return chrisporate_pro_is_team_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if client section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_client_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[client_section_enable]' )->value();
}

/**
 * Check if team section count enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_client_section_count_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[client_content_type]' )->value();
	return chrisporate_pro_is_client_section_enable( $control ) && ( ! in_array( $content_type, array( 'demo', 'post' ) ) );
}

/**
 * Check if client section content post enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_client_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[client_content_type]' )->value();
	return chrisporate_pro_is_client_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if client section content page enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_client_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[client_content_type]' )->value();
	return chrisporate_pro_is_client_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if client section content custom enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_client_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[client_content_type]' )->value();
	return chrisporate_pro_is_client_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if client section content category enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_client_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[client_content_type]' )->value();
	return chrisporate_pro_is_client_section_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if contact section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_contact_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[contact_section_enable]' )->value();
}

/**
 * Check if contact section title custom enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_contact_section_title_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[contact_title_type]' )->value();
	return chrisporate_pro_is_contact_section_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if contact section title post enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_contact_section_title_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[contact_title_type]' )->value();
	return chrisporate_pro_is_contact_section_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if contact section title page enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_contact_section_title_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[contact_title_type]' )->value();
	return chrisporate_pro_is_contact_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if map section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_map_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[map_section_enable]' )->value();
}

/**
 * Check if map section content shortcode enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_map_section_content_shortcode_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[map_content_type]' )->value();
	return chrisporate_pro_is_map_section_enable( $control ) && ( 'shortcode' === $content_type );
}

/**
 * Check if map section content embed enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_map_section_content_embed_enable( $control ) {
	$content_type = $control->manager->get_setting( 'chrisporate_pro_theme_options[map_content_type]' )->value();
	return chrisporate_pro_is_map_section_enable( $control ) && ( 'embed' === $content_type );
}

/**
 * Check if subscription section is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_subscription_section_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[subscription_section_enable]' )->value();
}

/**
 * Check if footer image is enabled.
 *
 * @since Chrisporate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function chrisporate_pro_is_footer_image_enable( $control ) {
	return $control->manager->get_setting( 'chrisporate_pro_theme_options[footer_image_enable]' )->value();
}
